@@ -12,6 +12,7 @@
 #include <QString>
 #include <QMap>
 #include <QTranslator>
+#include <QProcess>
 
 #ifdef Q_WS_MAEMO_5
 #include <QtDBus/QDBusConnection>
@@ -39,7 +40,7 @@ void Controller::toggleState() {
     }
 }
 
-QString Controller::getLanguage() {
+QString Controller::getLanguage() const {
     QMap<QString, QString> langs;
 
     QString english(tr("English"));
@@ -66,14 +67,14 @@ QString Controller::getLanguage() {
         while (query.next()) {
             language = query.value(0).toString();
         }
-//        qDebug() << language;
+        //        qDebug() << language;
         langCode = langs.value(language, "en");
     }
-//    qDebug() << langCode;
+    //    qDebug() << langCode;
     return langCode;
 }
 
-QStringList Controller::getDefaultAccountFromDB() {
+QStringList Controller::getDefaultAccountFromDB() const {
     QSqlDatabase db;
     db = QSqlDatabase::addDatabase("QSQLITE");
     db.setDatabaseName("/home/user/.config/cutetube/Databases/63db502ea46fc7fe74e01e615d2c00d6.sqlite");
@@ -87,7 +88,7 @@ QStringList Controller::getDefaultAccountFromDB() {
             account << query.value(0).toString();
             account << query.value(1).toString();
         }
-//        qDebug() << account;
+        //        qDebug() << account;
     }
     return account;
 }
@@ -130,17 +131,21 @@ void Controller::getMediaPlayerFromDB() {
         while (query.next()) {
             player = query.value(0).toString();
         }
-//        qDebug() << player;
+        //        qDebug() << player;
     }
     setMediaPlayer(player);
 }
 
-bool Controller::kmPlayerInstalled() {
-    bool isInstalled = false;
-    if ((QFile::exists("/opt/kmplayer/bin/kmplayer")) || (QFile::exists("/usr/bin/kmplayer"))) {
-        isInstalled = true;
+QStringList Controller::getInstalledMediaPlayers() const {
+    QStringList playerList;
+    playerList << "Media Player";
+    if ((QFile::exists("/usr/bin/mplayer"))) {
+        playerList << "MPlayer";
     }
-    return isInstalled;
+    if ((QFile::exists("/opt/kmplayer/bin/kmplayer")) || (QFile::exists("/usr/bin/kmplayer"))) {
+        playerList << "KMPlayer";
+    }
+    return playerList;
 }
 
 bool Controller::xTubeInstalled() {
@@ -155,11 +160,25 @@ void Controller::playVideo(const QString &url) {
 #ifdef Q_WS_MAEMO_5
     //    qDebug() << url;
     minimize();
-    QDBusConnection bus = QDBusConnection::sessionBus();
-    QDBusInterface dbus_iface("com.nokia." + mediaPlayer, "/com/nokia/" + mediaPlayer, "com.nokia." + mediaPlayer, bus);
-    dbus_iface.call("mime_open", url);
+    if (mediaPlayer == "mplayer") {
+        QStringList args;
+        args << "-cache" << "4096" << "-fs" << url;
+        QProcess *player = new QProcess();
+        connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
+        player->start("/usr/bin/mplayer", args);
+    }
+    else {
+        QDBusConnection bus = QDBusConnection::sessionBus();
+        QDBusInterface dbus_iface("com.nokia." + mediaPlayer, "/com/nokia/" + mediaPlayer, "com.nokia." + mediaPlayer, bus);
+        dbus_iface.call("mime_open", url);
+    }
     emit playbackStarted();
 #endif
+//    QStringList args;
+//    args << "-cache" << "4096" << "-fs" << url;
+//    QProcess *player = new QProcess();
+//    connect(player, SIGNAL(finished(int, QProcess::ExitStatus)), player, SLOT(deleteLater()));
+//    player->start("/usr/bin/mplayer", args);
 }
 
 void Controller::deleteVideo(const QString &path) {
