@@ -19,13 +19,13 @@ public:
 
 public slots:
 
-    QString getLanguage();
+    QString getLanguage() const;
     void setOrientation(const QString &orient);
-    bool kmPlayerInstalled();
+    QStringList getInstalledMediaPlayers() const;
     bool xTubeInstalled();
     void setMediaPlayer(const QString &player);
     void getMediaPlayerFromDB();
-    QStringList getDefaultAccountFromDB();
+    QStringList getDefaultAccountFromDB() const;
     void toggleState();
     void minimize();
     void playVideo(const QString &url);
