@@ -24,9 +24,13 @@
         <translation type="obsolete">cuteTube-QML - 0.4.4 in deutsch</translation>
     </message>
     <message>
-        <location filename="../AboutDialog.qml" line="44"/>
         <source>cuteTube-QML - 0.5.1</source>
-        <translation>cuteTube-QML - 0.5.1 in deutsch</translation>
+        <translation type="obsolete">cuteTube-QML - 0.5.1 in deutsch</translation>
+    </message>
+    <message>
+        <location filename="../AboutDialog.qml" line="44"/>
+        <source>cuteTube-QML - 0.6.1</source>
+        <translation>cuteTube-QML - 0.6.1 in deutsch</translation>
     </message>
     <message>
         <location filename="../AboutDialog.qml" line="56"/>
@@ -235,22 +239,22 @@
         <translation>Finnisch</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="131"/>
+        <location filename="../../../controller.cpp" line="168"/>
         <source>Video deleted from device</source>
         <translation>Video vom Gerät gelöscht</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="134"/>
+        <location filename="../../../controller.cpp" line="171"/>
         <source>Unable to delete video</source>
         <translation>Löschen des Videos nicht möglich</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="138"/>
+        <location filename="../../../controller.cpp" line="175"/>
         <source>Video not found</source>
         <translation>Video nicht gefunden</translation>
     </message>
     <message>
-        <location filename="../../../controller.cpp" line="193"/>
+        <location filename="../../../controller.cpp" line="230"/>
         <source>Copied to clipboard</source>
         <translation>In Zwischenablage kopiert</translation>
     </message>
@@ -588,194 +592,214 @@
 <context>
     <name>SettingsDialog</name>
     <message>
-        <location filename="../SettingsDialog.qml" line="125"/>
+        <location filename="../SettingsDialog.qml" line="143"/>
         <source>Your saved searches have been cleared</source>
         <translation>Die gespeicherten Suchen wurden gelöscht</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="128"/>
+        <location filename="../SettingsDialog.qml" line="146"/>
         <source>Database error. Unable to clear searches</source>
         <translation>Datenbankfehler. Konnte Konto nicht speichern</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="177"/>
+        <location filename="../SettingsDialog.qml" line="195"/>
         <source>Settings</source>
         <translation>Optionen</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="211"/>
+        <location filename="../SettingsDialog.qml" line="229"/>
         <source>Playback quality</source>
         <translation>Wiedergabequalität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="219"/>
+        <location filename="../SettingsDialog.qml" line="237"/>
         <source>Download quality</source>
         <translation>Downloadqualität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="227"/>
+        <location filename="../SettingsDialog.qml" line="245"/>
         <source>Start downloads</source>
         <translation>Downloads starten</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="235"/>
+        <location filename="../SettingsDialog.qml" line="253"/>
         <source>Download location</source>
         <translation>Downloadverzeichnis</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="243"/>
+        <location filename="../SettingsDialog.qml" line="269"/>
         <source>Screen orientation</source>
         <translation>Bildschirmausrichtung</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="251"/>
+        <location filename="../SettingsDialog.qml" line="277"/>
         <source>Media player</source>
         <translation>Media Player</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="116"/>
-        <location filename="../SettingsDialog.qml" line="268"/>
-        <location filename="../SettingsDialog.qml" line="422"/>
+        <location filename="../SettingsDialog.qml" line="134"/>
+        <location filename="../SettingsDialog.qml" line="294"/>
+        <location filename="../SettingsDialog.qml" line="466"/>
         <source>Language</source>
         <translation>Sprache</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="95"/>
-        <location filename="../SettingsDialog.qml" line="294"/>
+        <location filename="../SettingsDialog.qml" line="110"/>
+        <location filename="../SettingsDialog.qml" line="320"/>
         <source>Playback Quality</source>
         <translation>Wiedergabequalität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="98"/>
-        <location filename="../SettingsDialog.qml" line="312"/>
+        <location filename="../SettingsDialog.qml" line="113"/>
+        <location filename="../SettingsDialog.qml" line="338"/>
         <source>Download Quality</source>
         <translation>Downloadqualität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="101"/>
-        <location filename="../SettingsDialog.qml" line="330"/>
+        <location filename="../SettingsDialog.qml" line="116"/>
+        <location filename="../SettingsDialog.qml" line="356"/>
         <source>Start Downloads</source>
         <translation>Downloads starten</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="107"/>
-        <location filename="../SettingsDialog.qml" line="368"/>
+        <location filename="../SettingsDialog.qml" line="125"/>
+        <location filename="../SettingsDialog.qml" line="412"/>
         <source>Screen Orientation</source>
         <translation>Bildschirmausrichtung</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="20"/>
-        <location filename="../SettingsDialog.qml" line="110"/>
-        <location filename="../SettingsDialog.qml" line="386"/>
+        <location filename="../SettingsDialog.qml" line="22"/>
+        <location filename="../SettingsDialog.qml" line="128"/>
+        <location filename="../SettingsDialog.qml" line="430"/>
         <source>Media Player</source>
         <translation>Media Player</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="16"/>
         <location filename="../SettingsDialog.qml" line="17"/>
+        <location filename="../SettingsDialog.qml" line="18"/>
         <source>Mobile</source>
         <translation>Mobil</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="16"/>
         <location filename="../SettingsDialog.qml" line="17"/>
+        <location filename="../SettingsDialog.qml" line="18"/>
         <source>High Quality</source>
         <translation>Hohe Qualität</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="18"/>
-        <location filename="../SettingsDialog.qml" line="36"/>
-        <location filename="../SettingsDialog.qml" line="62"/>
+        <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="38"/>
+        <location filename="../SettingsDialog.qml" line="71"/>
         <source>Automatically</source>
         <translation>Automatisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="18"/>
-        <location filename="../SettingsDialog.qml" line="39"/>
+        <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="41"/>
         <source>Manually</source>
         <translation>Manuell</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="20"/>
+        <location filename="../SettingsDialog.qml" line="45"/>
+        <location filename="../SettingsDialog.qml" line="77"/>
+        <source>On</source>
+        <translation>Auf</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="20"/>
+        <location filename="../SettingsDialog.qml" line="48"/>
+        <source>Off</source>
+        <translation>Off</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="21"/>
         <source>Automatic</source>
         <translation>Automatisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="21"/>
         <source>Landscape</source>
         <translation>Querformat</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="19"/>
+        <location filename="../SettingsDialog.qml" line="21"/>
         <source>Portrait</source>
         <translation>Hochformat</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="23"/>
         <source>Light</source>
         <translation>Hell</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="21"/>
+        <location filename="../SettingsDialog.qml" line="23"/>
         <source>Dark</source>
         <translation>Dunkel</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="22"/>
+        <location filename="../SettingsDialog.qml" line="24"/>
         <source>English</source>
         <translation>Englisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="22"/>
+        <location filename="../SettingsDialog.qml" line="24"/>
         <source>German</source>
         <translation>Deutsch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="22"/>
+        <location filename="../SettingsDialog.qml" line="24"/>
         <source>Finnish</source>
         <translation>Finnisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="22"/>
+        <location filename="../SettingsDialog.qml" line="24"/>
         <source>Italian</source>
         <translation>Italienisch</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="35"/>
-        <location filename="../SettingsDialog.qml" line="63"/>
+        <location filename="../SettingsDialog.qml" line="37"/>
+        <location filename="../SettingsDialog.qml" line="72"/>
         <source>Queued</source>
         <translation>in Warteschlange</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="66"/>
+        <location filename="../SettingsDialog.qml" line="75"/>
         <source>Paused</source>
         <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="69"/>
+        <location filename="../SettingsDialog.qml" line="84"/>
         <source>Your settings have been saved</source>
         <translation>Ihre Einstellungen wurden gespeichert</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="74"/>
-        <location filename="../SettingsDialog.qml" line="104"/>
+        <location filename="../SettingsDialog.qml" line="89"/>
+        <location filename="../SettingsDialog.qml" line="119"/>
         <source>Download Path</source>
         <translation>Downloadverzeichnis</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="76"/>
+        <location filename="../SettingsDialog.qml" line="91"/>
         <source>Download Location</source>
         <translation>Downloadverzeichnis</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="113"/>
-        <location filename="../SettingsDialog.qml" line="259"/>
-        <location filename="../SettingsDialog.qml" line="404"/>
+        <location filename="../SettingsDialog.qml" line="122"/>
+        <location filename="../SettingsDialog.qml" line="261"/>
+        <location filename="../SettingsDialog.qml" line="394"/>
+        <source>Safe Search</source>
+        <translation>Sicher Suchlauf</translation>
+    </message>
+    <message>
+        <location filename="../SettingsDialog.qml" line="131"/>
+        <location filename="../SettingsDialog.qml" line="285"/>
+        <location filename="../SettingsDialog.qml" line="448"/>
         <source>Theme</source>
         <translation>Thema</translation>
     </message>
     <message>
-        <location filename="../SettingsDialog.qml" line="436"/>
+        <location filename="../SettingsDialog.qml" line="480"/>
         <source>Clear saved searches</source>
         <translation>Lösche Suche</translation>
     </message>
@@ -793,7 +817,7 @@
     <message>
         <location filename="../SubscriptionsView.qml" line="46"/>
         <source>You have unsubscribed to &apos;</source>
-        <translation>Du hast ein Abonnement bei</translation>
+        <translation>Du hast ein Abonnement bei </translation>
     </message>
     <message>
         <location filename="../SubscriptionsView.qml" line="105"/>
@@ -1129,6 +1153,12 @@
         <source>By </source>
         <translation>Von </translation>
     </message>
+    <message>
+        <location filename="../VideoInfoView.qml" line="442"/>
+        <location filename="../VideoInfoView.qml" line="445"/>
+        <source> on </source>
+        <translation> am </translation>
+    </message>
     <message>
         <location filename="../VideoInfoView.qml" line="511"/>
         <source>Views</source>
@@ -1227,108 +1257,93 @@
 <context>
     <name>Widget</name>
     <message>
-        <location filename="../Widget.qml" line="81"/>
         <source>Error: Unable to retrieve video</source>
-        <translation>Fehler: Kann Video nicht empfangen</translation>
+        <translation type="obsolete">Fehler: Kann Video nicht empfangen</translation>
+    </message>
+    <message>
+        <location filename="../Widget.qml" line="271"/>
+        <source>No videos found</source>
+        <translation>Keine Videos gefunden</translation>
     </message>
 </context>
 <context>
     <name>XHamsterInfoView</name>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="211"/>
         <source>Info</source>
-        <translation>Info</translation>
+        <translation type="obsolete">Info</translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="250"/>
         <source>Related</source>
-        <translation>Ähnliche</translation>
+        <translation type="obsolete">Ähnliche</translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="332"/>
-        <location filename="../XHamsterInfoView.qml" line="335"/>
         <source>By </source>
-        <translation>Von </translation>
+        <translation type="obsolete">Von </translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="334"/>
-        <location filename="../XHamsterInfoView.qml" line="337"/>
         <source> on </source>
-        <translation> am </translation>
+        <translation type="obsolete"> am </translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="353"/>
         <source>Views </source>
-        <translation>Aufrufe</translation>
+        <translation type="obsolete">Aufrufe</translation>
     </message>
     <message>
-        <location filename="../XHamsterInfoView.qml" line="359"/>
         <source>Tags</source>
-        <translation>Tags</translation>
+        <translation type="obsolete">Tags</translation>
     </message>
 </context>
 <context>
     <name>XHamsterListView</name>
     <message>
-        <location filename="../XHamsterListView.qml" line="148"/>
         <source>Multi-select</source>
-        <translation>Mehrfachauswahl</translation>
+        <translation type="obsolete">Mehrfachauswahl</translation>
     </message>
     <message>
-        <location filename="../XHamsterListView.qml" line="150"/>
         <source>Download video</source>
-        <translation>Video herrunterladen</translation>
+        <translation type="obsolete">Video herrunterladen</translation>
     </message>
     <message>
-        <location filename="../XHamsterListView.qml" line="186"/>
         <source>No videos found</source>
-        <translation>Keine Videos gefunden</translation>
+        <translation type="obsolete">Keine Videos gefunden</translation>
     </message>
 </context>
 <context>
     <name>YouJizzInfoView</name>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="65"/>
         <source>Copy to clipboard</source>
-        <translation>In Zwischenablage kopieren</translation>
+        <translation type="obsolete">In Zwischenablage kopieren</translation>
     </message>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="200"/>
         <source>Info</source>
-        <translation>Info</translation>
+        <translation type="obsolete">Info</translation>
     </message>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="239"/>
         <source>Related</source>
-        <translation>Ähnliche</translation>
+        <translation type="obsolete">Ähnliche</translation>
     </message>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="316"/>
         <source>Views </source>
-        <translation>Aufrufe</translation>
+        <translation type="obsolete">Aufrufe</translation>
     </message>
     <message>
-        <location filename="../YouJizzInfoView.qml" line="322"/>
         <source>Tags</source>
-        <translation>Tags</translation>
+        <translation type="obsolete">Tags</translation>
     </message>
 </context>
 <context>
     <name>YouJizzListView</name>
     <message>
-        <location filename="../YouJizzListView.qml" line="135"/>
         <source>Multi-select</source>
-        <translation>Mehrfachauswahl</translation>
+        <translation type="obsolete">Mehrfachauswahl</translation>
     </message>
     <message>
-        <location filename="../YouJizzListView.qml" line="137"/>
         <source>Download video</source>
-        <translation>Video herrunterladen</translation>
+        <translation type="obsolete">Video herrunterladen</translation>
     </message>
     <message>
-        <location filename="../YouJizzListView.qml" line="173"/>
         <source>No videos found</source>
-        <translation>Keine Videos gefunden</translation>
+        <translation type="obsolete">Keine Videos gefunden</translation>
     </message>
 </context>
 <context>
@@ -1349,34 +1364,34 @@
         <translation>Bei YouTube angemeldet als &apos;</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="115"/>
-        <location filename="../../../youtube.cpp" line="221"/>
+        <location filename="../../../youtube.cpp" line="120"/>
+        <location filename="../../../youtube.cpp" line="226"/>
         <source>Error - Server repsonse is: </source>
         <translation>Fehler - Serverantwort ist:</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="165"/>
-        <location filename="../../../youtube.cpp" line="173"/>
+        <location filename="../../../youtube.cpp" line="170"/>
+        <location filename="../../../youtube.cpp" line="178"/>
         <source>Upload aborted</source>
         <translation>Upload abgebrochen</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="180"/>
+        <location filename="../../../youtube.cpp" line="185"/>
         <source>Upload interrupted. Attempting to resume...</source>
         <translation>Upload unterbrochen. Versuche wiederaufnahme...</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="184"/>
+        <location filename="../../../youtube.cpp" line="189"/>
         <source>Upload failed</source>
         <translation>Upload fehlgeschlagen</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="190"/>
+        <location filename="../../../youtube.cpp" line="195"/>
         <source>Upload is completed</source>
         <translation>Upload ist komplett</translation>
     </message>
     <message>
-        <location filename="../../../youtube.cpp" line="383"/>
+        <location filename="../../../youtube.cpp" line="387"/>
         <source>Error: Unable to retrieve video</source>
         <translation>Fehler: Kann Video nicht empfangen</translation>
     </message>
@@ -1385,12 +1400,16 @@
     <name>main</name>
     <message>
         <location filename="../main.qml" line="18"/>
+        <source>Dark</source>
+        <translation>Dunkel</translation>
+    </message>
+    <message>
         <location filename="../main.qml" line="21"/>
         <location filename="../main.qml" line="22"/>
         <location filename="../main.qml" line="23"/>
         <location filename="../main.qml" line="24"/>
-        <source>Dark</source>
-        <translation>Dunkel</translation>
+        <source>Light</source>
+        <translation>Hell</translation>
     </message>
     <message>
         <location filename="../main.qml" line="109"/>
@@ -1518,7 +1537,7 @@
         <translation>bewertung</translation>
     </message>
     <message>
-        <location filename="../scripts/mainscripts.js" line="237"/>
+        <location filename="../scripts/mainscripts.js" line="239"/>
         <source>Search </source>
         <translation>Suchlauf</translation>
     </message>
@@ -1537,27 +1556,27 @@
         <translation>Pausiert</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="130"/>
+        <location filename="../scripts/settings.js" line="131"/>
         <source>Automatic</source>
         <translation>Automatisch</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="131"/>
+        <location filename="../scripts/settings.js" line="132"/>
         <source>Media Player</source>
         <translation>Media Player</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="132"/>
+        <location filename="../scripts/settings.js" line="133"/>
         <source>Date</source>
         <translation>Datum</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="133"/>
+        <location filename="../scripts/settings.js" line="134"/>
         <source>Dark</source>
         <translation>Dunkel</translation>
     </message>
     <message>
-        <location filename="../scripts/settings.js" line="134"/>
+        <location filename="../scripts/settings.js" line="135"/>
         <source>English</source>
         <translation>Englisch</translation>
     </message>
@@ -1565,37 +1584,28 @@
 <context>
     <name>xtube</name>
     <message>
-        <location filename="../scripts/xtube.js" line="7"/>
-        <location filename="../scripts/xtube.js" line="57"/>
         <source>date</source>
-        <translation>datum</translation>
+        <translation type="obsolete">datum</translation>
     </message>
     <message>
-        <location filename="../scripts/xtube.js" line="10"/>
         <source>views</source>
-        <translation>aufrufe</translation>
+        <translation type="obsolete">aufrufe</translation>
     </message>
     <message>
-        <location filename="../scripts/xtube.js" line="13"/>
         <source>rating</source>
-        <translation>bewertung</translation>
+        <translation type="obsolete">bewertung</translation>
     </message>
     <message>
-        <location filename="../scripts/xtube.js" line="18"/>
-        <location filename="../scripts/xtube.js" line="62"/>
         <source>Search </source>
-        <translation>Suche</translation>
+        <translation type="obsolete">Suche</translation>
     </message>
     <message>
-        <location filename="../scripts/xtube.js" line="39"/>
-        <location filename="../scripts/xtube.js" line="82"/>
         <source>Video Info</source>
-        <translation>Video Info</translation>
+        <translation type="obsolete">Video Info</translation>
     </message>
     <message>
-        <location filename="../scripts/xtube.js" line="57"/>
         <source>relevance</source>
-        <translation>relevanz</translation>
+        <translation type="obsolete">relevanz</translation>
     </message>
 </context>
 </TS>
