@@ -561,13 +561,13 @@
         <location filename="../SettingsDialog.qml" line="45"/>
         <location filename="../SettingsDialog.qml" line="77"/>
         <source>On</source>
-        <translation>Su</translation>
+        <translation>Attiva</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="20"/>
         <location filename="../SettingsDialog.qml" line="48"/>
         <source>Off</source>
-        <translation>Off</translation>
+        <translation>Disattiva</translation>
     </message>
     <message>
         <location filename="../SettingsDialog.qml" line="21"/>
