@@ -12,11 +12,11 @@ function restoreSettings() {
     Settings.initialize();
     cuteTubeTheme = Settings.getSetting("theme");
     Controller.setOrientation(Settings.getSetting("screenOrientation"));
-    if (Controller.kmPlayerInstalled()) {
+    if (Controller.getInstalledMediaPlayers().length > 1) {
         Controller.setMediaPlayer(Settings.getSetting("mediaPlayer"));
     }
     else {
-        Settings.setSetting("mediaPlayer", qsTr("Media Player"));
+        Settings.setSetting("mediaPlayer", "Media Player");
         Controller.setMediaPlayer("Media Player");
     }
     YouTube.setPlaybackQuality(Settings.getSetting("playbackQuality"));
